@@ -3,7 +3,8 @@
 /*----------------------------------------------------------------------
 -- This file is part of GNU MARST, an Algol-to-C translator.
 --
--- Copyright (C) 2000, 2001, 2002, 2007 Free Software Foundation, Inc.
+-- Copyright (C) 2000, 2001, 2002, 2007, 2025 Free Software Foundation,
+-- Inc.
 --
 -- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -134,9 +135,9 @@ int get_int(struct desc x)
 
 /*--------------------------------------------------------------------*/
 
-bool get_bool(struct desc x)
+Bool get_bool(struct desc x)
 {     /* returns value of Boolean formal parameter called by name */
-      bool val;
+      Bool val;
       switch (x.type)
       {  case 'b':
             val = (x.lval ? *x.u.bool_ptr : x.u.bool_val);
@@ -212,7 +213,7 @@ int set_int(struct desc x, int val)
 
 /*--------------------------------------------------------------------*/
 
-bool set_bool(struct desc x, bool val)
+Bool set_bool(struct desc x, Bool val)
 {     /* assigns value to Boolean formal parameter called by name */
       if (!x.lval)
          fault("assignment to a Boolean formal parameter called by name"
@@ -318,7 +319,11 @@ static struct dv *copy_dv(int own, struct dv *dope)
       struct dv *dv;
       int size;
       assert(1 <= dope->n && dope->n <= 9);
+#if 0 /* 05/X-2025; non-constant expression is non-standard feature */
       size = offsetof(struct dv, d[dope->n]);
+#else
+      size = offsetof(struct dv, d) + dope->n * sizeof dv->d[0];
+#endif
       dv = own ? my_malloc(size) : push_stack(size);
       memcpy(dv, dope, size);
       return dv;
@@ -348,7 +353,7 @@ static int array_size(int type, struct dv *dv)
       switch (type)
       {  case 'r': size = sizeof(double); break;
          case 'i': size = sizeof(int); break;
-         case 'b': size = sizeof(bool); break;
+         case 'b': size = sizeof(Bool); break;
          default:  assert(type != type);
       }
       for (k = 0; k < dv->n; k++)
@@ -569,14 +574,14 @@ int *loc_int(struct dv *dv, int n, ...)
 
 /*--------------------------------------------------------------------*/
 
-bool *loc_bool(struct dv *dv, int n, ...)
+Bool *loc_bool(struct dv *dv, int n, ...)
 {     /* returns address of subscripted variable of Boolean type */
       va_list arg;
       int loc;
       va_start(arg, n);
       loc = loc_elem(dv, n, arg);
       va_end(arg);
-      return (bool *)dv->base + loc;
+      return (Bool *)dv->base + loc;
 }
 
 /**********************************************************************/
@@ -619,8 +624,13 @@ void fault(char *fmt, ...)
          for (k = 0; k < CHANNEL_MAX; k++)
             if (status[k] == 'w') fflush(stream[k]);
       }
+#if 0 /* 06/X-2025 */
       /* and exit to the control program */
       exit(EXIT_FAILURE);
+#else
+      /* call abort for debugging purposes */
+      abort();
+#endif
       /* no return */
 }
 
@@ -657,7 +667,7 @@ static void connect(int channel, int mode)
             if (filename == NULL) filename = dd_name;
             stream[channel] = fopen(filename, mode == 'w' ? "w" : "r");
             if (stream[channel] == NULL)
-               fault("unable to connect channel %d to file `%s' for %s "
+               fault("unable to connect channel %d to file '%s' for %s "
                   "- %s", channel, filename,
                   mode == 'w' ? "output" : "input", strerror(errno));
             status[channel] = mode;
@@ -718,7 +728,7 @@ static char *input_data(int channel)
       while (!isspace(c))
       {  if (len == sizeof(str) - 1)
          {  str[len] = '\0';
-            fault("input data item `%.12s...' too long", str);
+            fault("input data item '%.12s...' too long", str);
          }
          str[len++] = (char)c;
          c = inchar(channel);
@@ -736,7 +746,7 @@ int ininteger(int channel)
       str = input_data(channel);
       x = strtol(str, &ptr, 10);
       if (*ptr != '\0')
-         fault("unable to convert `%s' to integer number", str);
+         fault("unable to convert '%s' to integer number", str);
       return x;
 }
 
@@ -758,7 +768,7 @@ double inreal(int channel)
       str = input_data(channel);
       x = strtod(str, &ptr);
       if (*ptr != '\0')
-         fault("unable to convert `%s' to real number", str);
+         fault("unable to convert '%s' to real number", str);
       return x;
 }
 
