@@ -3,7 +3,8 @@
 /*----------------------------------------------------------------------
 -- This file is part of GNU MARST, an Algol-to-C translator.
 --
--- Copyright (C) 2000, 2001, 2002, 2007 Free Software Foundation, Inc.
+-- Copyright (C) 2000, 2001, 2002, 2007, 2025 Free Software Foundation,
+-- Inc.
 --
 -- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -62,8 +63,8 @@ static void outarray(char *name, struct dv *dv, int type)
                base = ((int *)base) + 1;
                break;
             case 'b':
-               outputf("%s\n", *(bool *)base ? "true" : "false");
-               base = ((bool *)base) + 1;
+               outputf("%s\n", *(Bool *)base ? "true" : "false");
+               base = ((Bool *)base) + 1;
                break;
             default:
                assert(type != type);
@@ -118,7 +119,7 @@ void print(int n, ...)
                break;
             case F_BOOL:
                {  /* Boolean quantity */
-                  bool val = va_arg(arg, bool);
+                  Bool val = va_arg(arg, Bool);
                   if (name != NULL) outputf("%s = ", name);
                   outputf("%s\n", val ? "true" : "false");
                }
@@ -137,7 +138,7 @@ void print(int n, ...)
                   int type = (int)val.arg2;
                   assert(name != NULL);
                   if (dv->base == NULL)
-                     outputf("array `%s' has no elements\n", name);
+                     outputf("array '%s' has no elements\n", name);
                   else
                      outarray(name, dv, type);
                }
