@@ -3,8 +3,8 @@
 /*----------------------------------------------------------------------
 -- This file is part of GNU MARST, an Algol-to-C translator.
 --
--- Copyright (C) 2000, 2001, 2002, 2007, 2013 Free Software Foundation,
--- Inc.
+-- Copyright (C) 2000, 2001, 2002, 2007, 2013, 2025 Free Software
+-- Foundation, Inc.
 --
 -- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 
 /*--------------------------------------------------------------------*/
 
-static char *version = "MACVT -- Algol 60 Converter, Version 2.7";
+static char *version = "MACVT--Algol 60 Converter, Version 2.8";
 /* Version information. */
 
 static char *infilename = "";
